==> yuidocjs-0.3.5.tgz: package/tests/out/api.js <==
YUI.add("yuidoc-meta", function(Y) {
   Y.YUIDoc = { meta: {
    "classes": [
        "Anim",
        "AreaSeries",
        "AreaSplineSeries",
        "Axis",
        "AxisType",
        "BarSeries",
        "BottomAxisLayout",
        "CartesianChart",
        "CartesianSeries",
        "CategoryAxis",
        "Chart",
        "ChartBase",
        "ChartLegend",
        "ColumnSeries",
        "ComboSeries",
        "ComboSplineSeries",
        "CurveUtil",
        "Easing",
        "EasingFoo",
        "EllipseGroup",
        "Fills",
        "Foo.Bar",
        "Graph",
        "Gridlines",
        "GroupCircle",
        "GroupDiamond",
        "GroupRect",
        "Histogram",
        "HorizontalLegendLayout",
        "JSON",
        "LeftAxisLayout",
        "LineSeries",
        "Lines",
        "Main",
        "MarkerSeries",
        "NumericAxis",
        "OtherClass",
        "OtherClass2",
        "P.storage",
        "P.storage.LocalStore",
        "P.storage.Store",
        "PieChart",
        "PieSeries",
        "Plots",
        "Renderer",
        "RightAxisLayout",
        "ShapeGroup",
        "SplineSeries",
        "StackedAreaSeries",
        "StackedAreaSplineSeries",
        "StackedAxis",
        "StackedBarSeries",
        "StackedColumnSeries",
        "StackedComboSeries",
        "StackedComboSplineSeries",
        "StackedLineSeries",
        "StackedMarkerSeries",
        "StackedSplineSeries",
        "StackingUtil",
        "TimeAxis",
        "TopAxisLayout",
        "VerticalLegendLayout",
        "YUI~dump",
        "YUI~oop",
        "myclass",
        "mywidget.SubWidget",
        "mywidget.SuperWidget"
    ],
    "modules": [
        "ExampleModule",
        "P.storage",
        "anim",
        "anim-easing",
        "anim-easing-foo",
        "charts",
        "charts-legend",
        "dump",
        "foobar",
        "graphics",
        "json",
        "json-parse",
        "json-stringify",
        "myapp_views_index",
        "mymodule",
        "mysubmodule",
        "oop"
    ],
    "allModules": [
        {
            "displayName": "anim",
            "name": "anim",
            "description": "This is the Anim MODULE description"
        },
        {
            "displayName": "anim-easing",
            "name": "anim-easing",
            "description": "The easing module provides methods for customizing\nhow an animation behaves during each run."
        },
        {
            "displayName": "anim-easing-foo",
            "name": "anim-easing-foo",
            "description": "FOO FOO FOO FOO FOO The easing module provides methods for customizing"
        },
        {
            "displayName": "charts",
            "name": "charts",
            "description": "The Charts widget provides an api for displaying data\ngraphically."
        },
        {
            "displayName": "charts-legend",
            "name": "charts-legend",
            "description": "Adds legend functionality to charts."
        },
        {
            "displayName": "dump",
            "name": "dump",
            "description": "Returns a simple string representation of the object or array.\nOther types of objects will be returned unprocessed.  Arrays\nare expected to be indexed.  Use object notation for\nassociative arrays.\n\nIf included, the dump method is added to the YUI instance."
        },
        {
            "displayName": "ExampleModule",
            "name": "ExampleModule"
        },
        {
            "displayName": "foobar",
            "name": "foobar",
            "description": "Test Class"
        },
        {
            "displayName": "graphics",
            "name": "graphics",
            "description": "Abstract class for creating groups of shapes with the same styles and dimensions."
        },
        {
            "displayName": "json",
            "name": "json",
            "description": "<p>The JSON module adds support for serializing JavaScript objects into\nJSON strings and parsing JavaScript objects from strings in JSON format.</p>\n\n<p>The JSON namespace is added to your YUI instance including static methods\nY.JSON.parse(..) and Y.JSON.stringify(..).</p>\n\n<p>The functionality and method signatures follow the ECMAScript 5\nspecification.  In browsers with native JSON support, the native\nimplementation is used.</p>\n\n<p>The <code>json</code> module is a rollup of <code>json-parse</code> and\n<code>json-stringify</code>.</p>\n\n<p>As their names suggest, <code>json-parse</code> adds support for parsing\nJSON data (Y.JSON.parse) and <code>json-stringify</code> for serializing\nJavaScript data into JSON strings (Y.JSON.stringify).  You may choose to\ninclude either of the submodules individually if you don't need the\ncomplementary functionality, or include the rollup for both.</p>"
        },
        {
            "displayName": "json-parse",
            "name": "json-parse",
            "description": "Provides Y.JSON.parse method to accept JSON strings and return native\nJavaScript objects."
        },
        {
            "displayName": "json-stringify",
            "name": "json-stringify",
            "description": "Provides Y.JSON.stringify method for converting objects to JSON strings."
        },
        {
            "displayName": "myapp/views/index",
            "name": "myapp_views_index",
            "description": "This is a module with slashes in the name"
        },
        {
            "displayName": "mymodule",
            "name": "mymodule",
            "description": "The module"
        },
        {
            "displayName": "mysubmodule",
            "name": "mysubmodule",
            "description": "The submodule"
        },
        {
            "displayName": "oop",
            "name": "oop",
            "description": "Supplies object inheritance and manipulation utilities.  This adds\nadditional functionaity to what is provided in yui-base, and the\nmethods are applied directly to the YUI instance.  This module\nis required for most YUI components."
        },
        {
            "displayName": "P.storage",
            "name": "P.storage"
        }
    ]
} };
});

==> yuidocjs-0.3.29.tgz: package/tests/out/api.js <==
YUI.add("yuidoc-meta", function(Y) {
   Y.YUIDoc = { meta: {
    "classes": [
        "Anim",
        "AreaSeries",
        "AreaSplineSeries",
        "Axis",
        "AxisType",
        "BarSeries",
        "BottomAxisLayout",
        "CartesianChart",
        "CartesianSeries",
        "CategoryAxis",
        "Chart",
        "ChartBase",
        "ChartLegend",
        "ColumnSeries",
        "ComboSeries",
        "ComboSplineSeries",
        "CurveUtil",
        "Easing",
        "EasingFoo",
        "EllipseGroup",
        "Fills",
        "Foo.Bar",
        "Graph",
        "Gridlines",
        "GroupCircle",
        "GroupDiamond",
        "GroupRect",
        "Histogram",
        "HorizontalLegendLayout",
        "JSON",
        "LeftAxisLayout",
        "LineSeries",
        "Lines",
        "Main",
        "MarkerSeries",
        "NumericAxis",
        "OtherClass",
        "OtherClass2",
        "P.storage",
        "P.storage.LocalStore",
        "P.storage.Store",
        "PieChart",
        "PieSeries",
        "Plots",
        "Renderer",
        "RightAxisLayout",
        "ShapeGroup",
        "SplineSeries",
        "StackedAreaSeries",
        "StackedAreaSplineSeries",
        "StackedAxis",
        "StackedBarSeries",
        "StackedColumnSeries",
        "StackedComboSeries",
        "StackedComboSplineSeries",
        "StackedLineSeries",
        "StackedMarkerSeries",
        "StackedSplineSeries",
        "StackingUtil",
        "TimeAxis",
        "TopAxisLayout",
        "VerticalLegendLayout",
        "YUI~dump",
        "YUI~oop",
        "myclass",
        "mywidget.SubWidget",
        "mywidget.SubWidget2",
        "mywidget.SuperWidget"
    ],
    "modules": [
        "ExampleModule",
        "P.storage",
        "anim",
        "anim-easing",
        "anim-easing-foo",
        "charts",
        "charts-legend",
        "dump",
        "foobar",
        "graphics",
        "json",
        "json-parse",
        "json-stringify",
        "myapp_views_index",
        "mymodule",
        "mysubmodule",
        "oop"
    ],
    "allModules": [
        {
            "displayName": "anim",
            "name": "anim",
            "description": "This is the Anim MODULE description"
        },
        {
            "displayName": "anim-easing",
            "name": "anim-easing",
            "description": "The easing module provides methods for customizing\nhow an animation behaves during each run."
        },
        {
            "displayName": "anim-easing-foo",
            "name": "anim-easing-foo",
            "description": "FOO FOO FOO FOO FOO The easing module provides methods for customizing"
        },
        {
            "displayName": "charts",
            "name": "charts",
            "description": "The Charts widget provides an api for displaying data\ngraphically."
        },
        {
            "displayName": "charts-legend",
            "name": "charts-legend",
            "description": "Adds legend functionality to charts."
        },
        {
            "displayName": "dump",
            "name": "dump",
            "description": "Returns a simple string representation of the object or array.\nOther types of objects will be returned unprocessed.  Arrays\nare expected to be indexed.  Use object notation for\nassociative arrays.\n\nIf included, the dump method is added to the YUI instance."
        },
        {
            "displayName": "ExampleModule",
            "name": "ExampleModule",
            "description": "This is my example module"
        },
        {
            "displayName": "foobar",
            "name": "foobar",
            "description": "Test Class"
        },
        {
            "displayName": "graphics",
            "name": "graphics",
            "description": "Abstract class for creating groups of shapes with the same styles and dimensions."
        },
        {
            "displayName": "json",
            "name": "json",
            "description": "<p>The JSON module adds support for serializing JavaScript objects into\nJSON strings and parsing JavaScript objects from strings in JSON format.</p>\n\n<p>The JSON namespace is added to your YUI instance including static methods\nY.JSON.parse(..) and Y.JSON.stringify(..).</p>\n\n<p>The functionality and method signatures follow the ECMAScript 5\nspecification.  In browsers with native JSON support, the native\nimplementation is used.</p>\n\n<p>The <code>json</code> module is a rollup of <code>json-parse</code> and\n<code>json-stringify</code>.</p>\n\n<p>As their names suggest, <code>json-parse</code> adds support for parsing\nJSON data (Y.JSON.parse) and <code>json-stringify</code> for serializing\nJavaScript data into JSON strings (Y.JSON.stringify).  You may choose to\ninclude either of the submodules individually if you don't need the\ncomplementary functionality, or include the rollup for both.</p>"
        },
        {
            "displayName": "json-parse",
            "name": "json-parse",
            "description": "Provides Y.JSON.parse method to accept JSON strings and return native\nJavaScript objects."
        },
        {
            "displayName": "json-stringify",
            "name": "json-stringify",
            "description": "Provides Y.JSON.stringify method for converting objects to JSON strings."
        },
        {
            "displayName": "myapp/views/index",
            "name": "myapp_views_index",
            "description": "This is a module with slashes in the name"
        },
        {
            "displayName": "mymodule",
            "name": "mymodule",
            "description": "The module"
        },
        {
            "displayName": "mysubmodule",
            "name": "mysubmodule",
            "description": "The submodule"
        },
        {
            "displayName": "oop",
            "name": "oop",
            "description": "Supplies object inheritance and manipulation utilities.  This adds\nadditional functionaity to what is provided in yui-base, and the\nmethods are applied directly to the YUI instance.  This module\nis required for most YUI components."
        },
        {
            "displayName": "P.storage",
            "name": "P.storage"
        }
    ]
} };
});
